==> org.eclipse.pde.ui.source_3.15.200.v20240518-1954.jar: org/eclipse/pde/internal/ui/shared/target/Messages.java <==
/*******************************************************************************
 *  Copyright (c) 2005, 2021 IBM Corporation and others.
 *
 *  This program and the accompanying materials
 *  are made available under the terms of the Eclipse Public License 2.0
 *  which accompanies this distribution, and is available at
 *  https://www.eclipse.org/legal/epl-2.0/
 *
 *  SPDX-License-Identifier: EPL-2.0
 *
 *  Contributors:
 *      IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.internal.ui.shared.target;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.pde.internal.ui.shared.target.messages"; //$NON-NLS-1$

	public static String AddBundleContainerSelectionPage_1;
	public static String AddBundleContainerSelectionPage_10;
	public static String AddBundleContainerSelectionPage_2;
	public static String AddBundleContainerSelectionPage_3;
	public static String AddBundleContainerSelectionPage_4;
	public static String AddBundleContainerSelectionPage_6;
	public static String AddBundleContainerSelectionPage_7;
	public static String AddBundleContainerSelectionPage_9;
	public static String AddDirectoryContainerPage_0;
	public static String AddDirectoryContainerPage_1;
	public static String AddDirectoryContainerPage_2;
	public static String AddDirectoryContainerPage_3;
	public static String AddDirectoryContainerPage_4;
	public static String AddDirectoryContainerPage_5;
	public static String AddDirectoryContainerPage_6;
	public static String AddDirectoryContainerPage_9;
	public static String AddFeatureContainerPage_0;
	public static String AddFeatureContainerPage_1;
	public static String AddFeatureContainerPage_2;
	public static String AddFeatureContainerPage_3;
	public static String AddFeatureContainerPage_4;
	public static String AddFeatureContainersPage_0;
	public static String AddFeatureContainersPage_1;
	public static String AddFeatureContainersPage_2;
	public static String AddProfileContainerPage_0;
	public static String AddProfileContainerPage_1;
	public static String AddProfileContainerPage_2;
	public static String AddProfileContainerPage_3;
	public static String AddProfileContainerPage_4;
	public static String AddProfileContainerPage_5;
	public static String AddProfileContainerPage_6;
	public static String AddProfileContainerPage_8;
	public static String ArgumentsFromContainerSelectionDialog_0;
	public static String ArgumentsFromContainerSelectionDialog_1;
	public static String ArgumentsFromContainerSelectionDialog_2;
	public static String ArgumentsFromContainerSelectionDialog_3;
	public static String ArgumentsFromContainerSelectionDialog_4;
	public static String ArgumentsFromContainerSelectionDialog_5;
	public static String BundleContainerTable_Btn_Text_Add;
	public static String BundleContainerTable_Btn_Text_Edit;
	public static String BundleContainerTable_Btn_Text_Remove;
	public static String BundleContainerTable_Btn_Text_Update;
	public static String BundleContainerTable_Btn_Text_Refresh;
	public static String BundleContainerTable_Btn_Text_ExpandAll;
	public static String BundleContainerTable_Btn_Text_CollapseAll;
	public static String BundleContainerTable_8;
	public static String BundleContainerTable_9;
	public static String BundleContainerTable_10;
	public static String BundleContainerTable_Btn_Text_Enable;
	public static String BundleContainerTable_Btn_Text_Disable;
	public static String BundleContainerTable_Btn_Text_Toggle;
	public static String BundleContainerTable_14;
	public static String BundleContainerTable_15;

	public static String CopyLocationAction_copyLocation;
	public static String EditBundleContainerWizard_0;
	public static String EditDirectoryContainerPage_0;
	public static String EditDirectoryContainerPage_1;
	public static String EditDirectoryContainerPage_3;
	public static String EditFeatureContainerPage_0;
	public static String EditFeatureContainerPage_1;
	public static String EditFeatureContainerPage_2;
	public static String EditFeatureContainerPage_3;
	public static String EditFeatureContainerPage_4;
	public static String EditFeatureContainerPage_5;
	public static String EditIUContainerPage_0;
	public static String EditIUContainerPage_1;
	public static String EditIUContainerPage_10;
	public static String EditIUContainerPage_11;
	public static String EditIUContainerPage_12;
	public static String EditIUContainerPage_13;
	public static String EditIUContainerPage_14;
	public static String EditIUContainerPage_15;
	public static String EditIUContainerPage_16;
	public static String EditIUContainerPage_17;
	public static String EditIUContainerPage_2;
	public static String EditIUContainerPage_3;
	public static String EditIUContainerPage_4;
	public static String EditIUContainerPage_5;
	public static String EditIUContainerPage_6;
	public static String EditIUContainerPage_7;
	public static String EditIUContainerPage_8;
	public static String EditIUContainerPage_9;
	public static String EditIUContainerPage_IncludeConfigurePhase;
	public static String EditIUContainerPage_itemSelected;
	public static String EditIUContainerPage_itemsSelected;
	public static String EditProfileContainerPage_1;
	public static String EditProfileContainerPage_2;
	public static String EditProfileContainerPage_3;
	public static String Errors_CreationError;
	public static String Errors_CreationError_NoWizard;
	public static String FeatureImportWizard_DetailedPage_problemsLoading;
	public static String FeatureImportWizardPage_importHasInvalid;
	public static String IncludedBundlesTree_0;
	public static String IncludedBundlesTree_1;
	public static String IncludedBundlesTree_2;
	public static String IncludedBundlesTree_3;

	public static String IUFactory_taskDeleteProfile;

	public static String IUFactory_taskRefreshRepositories;

	public static String IUFactory_errorRefreshRepositories;
	public static String PreviewContainerPage_0;
	public static String PreviewContainerPage_1;
	public static String PreviewContainerPage_2;
	public static String PreviewContainerPage_3;
	public static String TargetContentsGroup_0;
	public static String TargetContentsGroup_1;
	public static String TargetContentsGroup_10;
	public static String TargetContentsGroup_11;
	public static String TargetContentsGroup_2;
	public static String TargetContentsGroup_3;
	public static String TargetContentsGroup_4;
	public static String TargetContentsGroup_5;
	public static String TargetContentsGroup_8;
	public static String TargetContentsGroup_9;
	public static String TargetContentsGroup_collapseAll;
	public static String TargetContentsGroup_FeatureMode;
	public static String TargetContentsGroup_ManageUsing;
	public static String TargetContentsGroup_OtherPluginsParent;
	public static String TargetContentsGroup_PluginMode;
	public static String TargetContentsGroup_resolveCancelled;

	public static String TargetLocationsGroup_update;
	public static String TargetLocationsGroup_refresh;
	public static String TargetLocationsGroup_1;

	public static String TargetLocationsGroup_TargetUpdateErrorDialog;
	public static String TargetStatus_NoActiveTargetPlatformStatus;
	public static String TargetStatus_TargetStatusDefaultString;
	public static String TargetStatus_UnresolvedTarget;
	public static String TargetStatus_UnresolvedTargetStatus;
	public static String UpdateTargetJob_TargetUpdateFailedStatus;
	public static String UpdateTargetJob_TargetUpdateSuccessStatus;
	public static String UpdateTargetJob_UpdateJobName;
	public static String UpdateTargetJob_UpdatingTarget;
	public static String EditTargetContainerPage_Add_Title;
	public static String EditTargetContainerPage_Edit_Title;
	public static String EditTargetContainerPage_Message;
	public static String EditTargetContainerPage_Not_A_File;
	public static String EditRepositoryContainerPage_Message;
	public static String EditRepositoryContainerPage_Add_Title;
	public static String EditRepositoryContainerPage_Edit_Title;
	public static String SelectRepositoryContentPage_Title;
	public static String SelectRepositoryContentPage_Description;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}

==> org.eclipse.pde.ui.source_3.15.400.v20241111-2035.jar: org/eclipse/pde/internal/ui/shared/target/Messages.java <==
/*******************************************************************************
 *  Copyright (c) 2005, 2021 IBM Corporation and others.
 *
 *  This program and the accompanying materials
 *  are made available under the terms of the Eclipse Public License 2.0
 *  which accompanies this distribution, and is available at
 *  https://www.eclipse.org/legal/epl-2.0/
 *
 *  SPDX-License-Identifier: EPL-2.0
 *
 *  Contributors:
 *      IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.pde.internal.ui.shared.target;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = "org.eclipse.pde.internal.ui.shared.target.messages"; //$NON-NLS-1$

	public static String AddBundleContainerSelectionPage_1;
	public static String AddBundleContainerSelectionPage_10;
	public static String AddBundleContainerSelectionPage_2;
	public static String AddBundleContainerSelectionPage_3;
	public static String AddBundleContainerSelectionPage_4;
	public static String AddBundleContainerSelectionPage_6;
	public static String AddBundleContainerSelectionPage_7;
	public static String AddBundleContainerSelectionPage_9;
	public static String AddDirectoryContainerPage_0;
	public static String AddDirectoryContainerPage_1;
	public static String AddDirectoryContainerPage_2;
	public static String AddDirectoryContainerPage_3;
	public static String AddDirectoryContainerPage_4;
	public static String AddDirectoryContainerPage_5;
	public static String AddDirectoryContainerPage_6;
	public static String AddDirectoryContainerPage_9;
	public static String AddFeatureContainerPage_0;
	public static String AddFeatureContainerPage_1;
	public static String AddFeatureContainerPage_2;
	public static String AddFeatureContainerPage_3;
	public static String AddFeatureContainerPage_4;
	public static String AddFeatureContainersPage_0;
	public static String AddFeatureContainersPage_1;
	public static String AddFeatureContainersPage_2;
	public static String AddProfileContainerPage_0;
	public static String AddProfileContainerPage_1;
	public static String AddProfileContainerPage_2;
	public static String AddProfileContainerPage_3;
	public static String AddProfileContainerPage_4;
	public static String AddProfileContainerPage_5;
	public static String AddProfileContainerPage_6;
	public static String AddProfileContainerPage_8;
	public static String ArgumentsFromContainerSelectionDialog_0;
	public static String ArgumentsFromContainerSelectionDialog_1;
	public static String ArgumentsFromContainerSelectionDialog_2;
	public static String ArgumentsFromContainerSelectionDialog_3;
	public static String ArgumentsFromContainerSelectionDialog_4;
	public static String ArgumentsFromContainerSelectionDialog_5;
	public static String BundleContainerTable_Btn_Text_Add;
	public static String BundleContainerTable_Btn_Text_Edit;
	public static String BundleContainerTable_Btn_Text_Remove;
	public static String BundleContainerTable_Btn_Text_Update;
	public static String BundleContainerTable_Btn_Text_Refresh;
	public static String BundleContainerTable_Btn_Text_ExpandAll;
	public static String BundleContainerTable_Btn_Text_CollapseAll;
	public static String BundleContainerTable_8;
	public static String BundleContainerTable_9;
	public static String BundleContainerTable_10;
	public static String BundleContainerTable_Btn_Text_Enable;
	public static String BundleContainerTable_Btn_Text_Disable;
	public static String BundleContainerTable_Btn_Text_Toggle;
	public static String BundleContainerTable_14;
	public static String BundleContainerTable_15;

	public static String CopyLocationAction_copyLocation;
	public static String EditBundleContainerWizard_0;
	public static String EditDirectoryContainerPage_0;
	public static String EditDirectoryContainerPage_1;
	public static String EditDirectoryContainerPage_3;
	public static String EditFeatureContainerPage_0;
	public static String EditFeatureContainerPage_1;
	public static String EditFeatureContainerPage_2;
	public static String EditFeatureContainerPage_3;
	public static String EditFeatureContainerPage_4;
	public static String EditFeatureContainerPage_5;
	public static String EditIUContainerPage_0;
	public static String EditIUContainerPage_1;
	public static String EditIUContainerPage_10;
	public static String EditIUContainerPage_11;
	public static String EditIUContainerPage_12;
	public static String EditIUContainerPage_13;
	public static String EditIUContainerPage_14;
	public static String EditIUContainerPage_15;
	public static String EditIUContainerPage_16;
	public static String EditIUContainerPage_17;
	public static String EditIUContainerPage_2;
	public static String EditIUContainerPage_3;
	public static String EditIUContainerPage_4;
	public static String EditIUContainerPage_5;
	public static String EditIUContainerPage_6;
	public static String EditIUContainerPage_7;
	public static String EditIUContainerPage_8;
	public static String EditIUContainerPage_9;
	public static String EditIUContainerPage_IncludeConfigurePhase;
	public static String EditIUContainerPage_itemSelected;
	public static String EditIUContainerPage_itemsSelected;
	public static String EditIUContainerPage_VersionSpecification_Label;
	public static String EditIUContainerPage_Latest_Label;
	public static String EditProfileContainerPage_1;
	public static String EditProfileContainerPage_2;
	public static String EditProfileContainerPage_3;
	public static String Errors_CreationError;
	public static String Errors_CreationError_NoWizard;
	public static String FeatureImportWizard_DetailedPage_problemsLoading;
	public static String FeatureImportWizardPage_importHasInvalid;
	public static String IncludedBundlesTree_0;
	public static String IncludedBundlesTree_1;
	public static String IncludedBundlesTree_2;
	public static String IncludedBundlesTree_3;

	public static String IUFactory_taskDeleteProfile;

	public static String IUFactory_taskRefreshRepositories;

	public static String IUFactory_errorRefreshRepositories;
	public static String PreviewContainerPage_0;
	public static String PreviewContainerPage_1;
	public static String PreviewContainerPage_2;
	public static String PreviewContainerPage_3;
	public static String TargetContentsGroup_0;
	public static String TargetContentsGroup_1;
	public static String TargetContentsGroup_10;
	public static String TargetContentsGroup_11;
	public static String TargetContentsGroup_2;
	public static String TargetContentsGroup_3;
	public static String TargetContentsGroup_4;
	public static String TargetContentsGroup_5;
	public static String TargetContentsGroup_8;
	public static String TargetContentsGroup_9;
	public static String TargetContentsGroup_collapseAll;
	public static String TargetContentsGroup_FeatureMode;
	public static String TargetContentsGroup_ManageUsing;
	public static String TargetContentsGroup_OtherPluginsParent;
	public static String TargetContentsGroup_PluginMode;
	public static String TargetContentsGroup_resolveCancelled;

	public static String TargetLocationsGroup_update;
	public static String TargetLocationsGroup_refresh;
	public static String TargetLocationsGroup_1;

	public static String TargetLocationsGroup_TargetUpdateErrorDialog;
	public static String TargetStatus_NoActiveTargetPlatformStatus;
	public static String TargetStatus_TargetStatusDefaultString;
	public static String TargetStatus_UnresolvedTarget;
	public static String TargetStatus_UnresolvedTargetStatus;
	public static String UpdateTargetJob_TargetUpdateFailedStatus;
	public static String UpdateTargetJob_TargetUpdateSuccessStatus;
	public static String UpdateTargetJob_UpdateJobName;
	public static String UpdateTargetJob_UpdatingTarget;
	public static String EditTargetContainerPage_Add_Title;
	public static String EditTargetContainerPage_Edit_Title;
	public static String EditTargetContainerPage_Message;
	public static String EditTargetContainerPage_Not_A_File;
	public static String EditRepositoryContainerPage_Message;
	public static String EditRepositoryContainerPage_Add_Title;
	public static String EditRepositoryContainerPage_Edit_Title;
	public static String SelectRepositoryContentPage_Title;
	public static String SelectRepositoryContentPage_Description;

	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() {
	}
}
